(function() {
	'use strict';

	angular
		.module('barebone.page')
		.controller('BusseatController', BusseatController);

	BusseatController.$inject = [
		'$scope',
		'busService',
		'AppDB',
		'$timeout',
		'$state',
		'$stateParams',
		'$rootScope',
		'$ionicPopup',
		'$interval',
		'motion',
		'bookingMap',
		'bus'
	];

	/* @ngInject */
	function BusseatController(
		$scope, busService,AppDB, $timeout,$state,$stateParams,$rootScope,$ionicPopup,$interval,motion,bookingMap,bus) {

		var searchResult = $rootScope.searchResult;
		var userInfo     = $rootScope.userInfo || {};

		$rootScope.selected_seat = '';
		$rootScope.seat_no = '';
		$rootScope.adult = searchResult.adult;
		$rootScope.counter = 0;

		var vm = angular.extend(this, {
			from         : searchResult.from_destination,
			to 			 : searchResult.to_destination,
			userInfo	 : userInfo,
			adult 		 : $rootScope.adult,
			type         : searchResult.type,
			promo_code   : searchResult.promo_code,
			bus 		 : bus,
		traveldate 		 : searchResult.traveldate,
			title  		 : $rootScope.appLang.seat_title,
			bookSeats	 : bookSeats,
			selected_seat: $rootScope.selected_seat,
			seat_no		 : $rootScope.seat_no,
			seat_load	 : false,
			bookingMap	 : bookingMap.bookingMap,
		booked_user_json : bookingMap.booked_user_json,
			counter		 : 0,
		 selectedSeats   : '',
		 disabledSeat    : false,
			total 		 : 0,
			legend		 : '',
		stopTimeInt		 : '',
			busId  		 : '',
			seatId 		 : '',
		 seat_plan 		 : ''
		});

		(function activate() {

		if(vm.type == 'local'){
			vm.price   = parseFloat(vm.bus.local_sell_price);
		}
		else{
			vm.price   = parseFloat(vm.bus.foreigner_sell_price);
		}

		vm.total_amount	= (vm.adult*vm.price);
		
		var busId = parseInt($stateParams.busId);
		var seatId = parseInt($stateParams.seatId);

		vm.busId = busId;
		vm.seatId = seatId;
		
		busService.getSeatviews(busId,seatId,vm.adult,vm.traveldate)
				.then(function(seats) {		
					if(seats.avaliable_seat){
						  vm.seat_plan = seats.seat_plan;
						  
						  	vm.stopTimeInt = $interval(function() {
								$rootScope.disableLoader = true;
								Seatblocked();
							},7000);

						  vm.seat_load = true;
					}
					else{
						if($rootScope.appType == 'bus'){
							$ionicPopup.alert({
							    title: 'Sorry',
							    template: $rootScope.appLang.sold_out_seat
							  });
						}
						else{	
							$state.go('app.busbook', {busId: busId});
						}
					}

				});

			motion.expandHeader();
			motion.ink();

		})();

		function Seatblocked(){

			busService.getSeatblocked(vm.busId,vm.seatId,vm.traveldate)
				  	.then(function(seats) {
				  		vm.bookingMap = seats.bookingMap;
				  		vm.booked_user_json = seats.booked_user_json;
				  	});

		}

		function bookSeats(){

			vm.disabledSeat = true;
			var traveldate = vm.traveldate;
			var sdate = traveldate.split('-');
			if (sdate[0].length == 1)
		    {
		        traveldate = "0" + traveldate;
		    }
		    var selected_seat = $rootScope.selected_seat;
		    var seat_no = $rootScope.seat_no;
		    var seat_count = ((seat_no.split(',')).filter(function(seat){
							  return seat.length > 0;
							})).length;

		    if(seat_count == vm.adult){

		    	busService.bookedSeat(vm.busId,vm.seatId,traveldate,selected_seat,vm.total_amount,vm.adult,vm.promo_code)
				  	.then(function(seat) {

				  		$rootScope.searchResult.selected_seat = selected_seat;
						$rootScope.searchResult.seat_no = seat_no;
						$rootScope.searchResult.seat_id = vm.seatId;

						if(typeof vm.stopTimeInt != 'undefined'){
							$interval.cancel(vm.stopTimeInt);
						}

				  		$rootScope.seatExpirymin = seat.expiry;
				  		$rootScope.offerAmount = seat.offer_amount;
				  		$state.go('app.busbook', {busId: vm.busId});

				  	},function(error){
						vm.disabledSeat = false;
						vm.selected_seat = '';
						vm.seat_no = '';
						vm.counter = 0;
						$rootScope.searchResult.selected_seat = '';
						$rootScope.searchResult.seat_no = '';
				  	});
		    }
		    else{

		    	$ionicPopup.alert({
							    title: 'Invalid!',
							    template: 'You must need choose '+vm.adult+' bus seat(s) to book.'
							  });
		    	vm.disabledSeat = false;
				vm.selected_seat = '';
				vm.seat_no = '';
				vm.counter = 0;
				$rootScope.searchResult.selected_seat = '';
				$rootScope.searchResult.seat_no = '';
		    }
			
		}

		// ******************************************************
		// var tempList = AppDB.get('app.busseat');
		// vm.page  = JSON.parse(tempList.data).result;

		// pageService.getAbout()
		// 	.then(function(data) {
		// 		vm.page = data;
		// 	});

		


	}
})();