(function() {
	'use strict';

	angular
		.module('barebone.mybooking')
		.controller('MybookingController', MybookingController);

	MybookingController.$inject = [
		'$scope',
		'mybookingService',
		'FontDetectService',
		'$rootScope',
		'$timeout',
		'$state',
		'$auth',
		'$ionicPopup',
		'$ionicModal',
		'motion',
		'$cordovaPrinter'
	];

	/* @ngInject */
	function MybookingController($scope, mybookingService,FontDetectService,$rootScope,$timeout,$state,$auth,$ionicPopup,$ionicModal,motion,$cordovaPrinter) {

		$scope.today = new Date();
		
		var vm = angular.extend(this, {
			userprofile : $rootScope.userInfo,
			closeModal  : closeModal,
			loadbooking : loadbooking,
			showDes     : showDes,
			showPayment : showPayment,
			page 		 : 1,
			totalPages	 : 1,
			printTicket     : printTicket,
			moreDataCanBeLoaded : moreDataCanBeLoaded,
			loadMore : loadMore,
			   bookings : {}
		});

		$ionicModal.fromTemplateUrl('scripts/mybooking/booking-modal.html', {
				    vm: vm,
				    scope: $scope,
				    animation: 'slide-in-up'
		}).then(function(modal) {
				    $scope.modal = modal;
		});
		
		(function activate() {
			mybookingService.getBooking(vm.page)
			.then(function(data) {
				vm.totalPages = data.data.last_page;		
				vm.bookings = data.data.data;
			});
			motion.expandHeader();
		})();
		function detectFont(text){
			return FontDetectService.fontDetect(text);
		}
		function moreDataCanBeLoaded(){
			return vm.totalPages > vm.page;
		}

		function loadbooking() {
			vm.page = 1;
			mybookingService.getBooking(vm.page)
			.then(function(data) {
				vm.totalPages = data.data.last_page;		
				vm.bookings = data.data.data;
				$scope.$broadcast('scroll.refreshComplete');
			});
		}

		function printTicket(ticket_url){
			if($cordovaPrinter.isAvailable()) {
				$rootScope.$broadcast('loading:show');
	            $cordovaPrinter.print(ticket_url,{ duplex: 'none' }, function (res) {
				    $rootScope.$broadcast('loading:hide');
				});
	        } else {
	            alert("Printing is not available on device");
	        }
		}
		
		function loadMore() {
			vm.page += 1;
			mybookingService.getBooking(vm.page)
			.then(function(data) {
				vm.totalPages = data.data.last_page;
				var new_bookings = data.data.data;
				vm.bookings = vm.bookings.concat(new_bookings);
				$scope.$broadcast('scroll.infiniteScrollComplete');
			});
		}

		function showDes(des){
	 	 
	 	 	  vm.des = des;

			  $scope.modal.show();		

			  //Cleanup the modal when we're done with it!
			  $scope.$on('$destroy', function() {
			    $scope.modal.remove();
			  });
			  // Execute action on hide modal
			  $scope.$on('modal.hidden', function() {
			    // Execute action
			  });
			  // Execute action on remove modal
			  $scope.$on('modal.removed', function() {
			    // Execute action
			  });

		}

		function showPayment(ref){
	 	 
	 	 	for (var i = 0; i < vm.bookings.length; i++) {
	          if(vm.bookings[i].ref == ref)
	            var data = vm.bookings[i];            
	        }

          if(data.payment_method == 'transfer'){
        	
			var info = '<h5>Transfer Information</h5>'+
					'<span style="color:red;" >Your Booked Ticket amount need to Transfer to '+ $rootScope.appName +' Bank Account with below informations.</span><br><br>'
					+'<span style="color:red;margin-top:15px;" >'
					+'ေငြလဲြရမည့္ Account No. - '+data.bank_name+'<br>'
					+'ေငြလဲြရမည့္ Amount - '+data.amount+'<br>'
					+'Payment Description - Payment for Ticket No. '+ data.b_ref
					+'<br>Booked Ticket No. - ' + data.b_ref
					+'<br>မွတ္ခ်က္ - ' + data.bank_remark;
				if(data.payment_complete){
					info = info +'<br><br>Status : We received your transfer boooked ticket amount';
				}
				else{
					info = info +'<br><br>Note : We didn\'t get your transfer boooked ticket amount!';
				}
	        }   
	        else if(data.payment_method == 'onetwothree'){
	        	var info = '<h5>By OneTwoThree Payment<h5>';
	        	if(data.payment_complete){
					info = info +'<br><br>Status : We received your transfer boooked ticket amount';
				}
				else{
					info = info +'<br><br>Note : We didn\'t get your boooked ticket amount via OneTwoThree!';
				}
	        }   
	        else if(data.payment_method == 'paypal'){
	        	var info = '<h5>By Paypal Payment<h5>';
	        			if(data.payment_complete){
					info = info +'<br><br>Status : We received your transfer boooked ticket amount';
				}
				else{
					info = info +'<br><br>Note : We didn\'t get your boooked ticket amount via Paypal!';
				}
	        }   
	        else if(data.payment_method == 'visa_master'){
	        	var info = '<h5>By Visa/Master Payment<h5>';
	        			if(data.payment_complete){
					info = info +'<br><br>Status : We received your transfer boooked ticket amount';
				}
				else{
					info = info +'<br><br>Note : We didn\'t get your boooked ticket amount via Visa/Master!';
				}
	        }
	        else if(data.payment_method == 'truemoney'){
	        	var info = '<h5>By True Money Payment<h5>';
	        			if(data.payment_complete){
					info = info +'<br><br>Status : We received your transfer boooked ticket amount';
				}
				else{
					info = info +'<br><br>Note : We didn\'t get your boooked ticket amount via True Money!';
				}
	        } 
	        else if(data.payment_method == 'mab'){
	        	var info = '<h5>By MAB Payment<h5>';
	        			if(data.payment_complete){
					info = info +'<br><br>Status : We received your transfer boooked ticket amount';
				}
				else{
					info = info +'<br><br>Note : We didn\'t get your boooked ticket amount via MAB Mobile Banking!';
				}
	        } 
	        else if(data.payment_method == 'account'){
	        	var info = '<h5>By Credits/Deposit Payment<h5>';
	        			if(data.payment_complete){
					info = info +'<br><br>Status : We received your transfer boooked ticket amount';
				}
				else{
					info = info +'<br><br>Note : We didn\'t get your boooked ticket amount via Credits/Deposit Account!';
				}
	        }    
	        else{
	        	var info = '<h5>MPU Payment<h5>';

	        	if(data.payment_complete){
					info = info +'<br><br>Status : We received your transfer boooked ticket amount';
				}
				else{
					info = info +'<br><br>Note : We didn\'t get your boooked ticket amount via MPU!';
				}

	        }    


	 	 	  vm.des = info;

			  $scope.modal.show();		

			  //Cleanup the modal when we're done with it!
			  $scope.$on('$destroy', function() {
			    $scope.modal.remove();
			  });
			  // Execute action on hide modal
			  $scope.$on('modal.hidden', function() {
			    // Execute action
			  });
			  // Execute action on remove modal
			  $scope.$on('modal.removed', function() {
			    // Execute action
			  });

		}

		function closeModal(){

			$scope.modal.hide();

		}


	}
})();